@@ -1,7 +1,7 @@
 package Org::To::HTML;
 
 our $DATE = '2016-11-14'; # DATE
-our $VERSION = '0.18'; # VERSION
+our $VERSION = '0.19'; # VERSION
 
 use 5.010;
 use Log::Any::IfLOG '$log';
@@ -397,7 +397,7 @@ Org::To::HTML - Export Org document to HTML
 
 =head1 VERSION
 
-This document describes version 0.18 of Org::To::HTML (from Perl distribution Org-To-HTML), released on 2016-11-14.
+This document describes version 0.19 of Org::To::HTML (from Perl distribution Org-To-HTML), released on 2016-11-14.
 
 =head1 SYNOPSIS
 
@@ -425,6 +425,9 @@ Export Org format to HTML. To customize, you can subclass this module.
 
 A command-line utility is included: L<org-to-html>.
 
+Note that this module is just a simple exporter, for "serious" works you'll
+probably want to use the exporting features or L<org-mode|http://orgmode.org>.
+
 =head1 new(%args)
 
 =head2 $exp->export_document($doc) => HTML
